package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.IBlackListService;
import com.mdd.admin.validate.BlackListCreateValidate;
import com.mdd.admin.validate.BlackListSearchValidate;
import com.mdd.admin.validate.BlackListUpdateValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.BlackListDetailVo;
import com.mdd.admin.vo.BlackListListedVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.BlackList;
import com.mdd.common.mapper.BlackListMapper;
import com.mdd.common.util.TimeUtils;
import java.lang.invoke.SerializedLambda;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class BlackListServiceImpl implements IBlackListService {
   @Resource
   BlackListMapper blackListMapper;

   public PageResult<BlackListListedVo> list(PageValidate pageValidate, BlackListSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      QueryWrapper<BlackList> queryWrapper = new QueryWrapper();
      queryWrapper.orderByDesc("black_id");
      this.blackListMapper.setSearch(queryWrapper, searchValidate, new String[]{"=:type:int", "=:ip:str", "=:orderId@order_id:int"});
      IPage<BlackList> iPage = this.blackListMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<BlackListListedVo> list = new LinkedList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         BlackList item = (BlackList)var8.next();
         BlackListListedVo vo = new BlackListListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public BlackListDetailVo detail(Integer id) {
      BlackList model = (BlackList)this.blackListMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("black_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在");
      BlackListDetailVo vo = new BlackListDetailVo();
      BeanUtils.copyProperties(model, vo);
      return vo;
   }

   public void add(BlackListCreateValidate createValidate) {
      LambdaQueryWrapper<BlackList> wrapper = new LambdaQueryWrapper();
      wrapper.eq(BlackList::getIp, createValidate.getIp());
      if (this.blackListMapper.selectCount(wrapper) <= 0L) {
         BlackList model = new BlackList();
         model.setType(createValidate.getType());
         model.setIp(createValidate.getIp());
         model.setOrderId(createValidate.getOrderId());
         model.setCreateTime(System.currentTimeMillis() / 1000L);
         this.blackListMapper.insert(model);
      }
   }

   public void edit(BlackListUpdateValidate updateValidate) {
      BlackList model = (BlackList)this.blackListMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("black_id", updateValidate.getBlackId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setType(updateValidate.getType());
      model.setIp(updateValidate.getIp());
      model.setOrderId(updateValidate.getOrderId());
      this.blackListMapper.updateById(model);
   }

   public void delAll() {
      this.blackListMapper.delete(new QueryWrapper());
   }

   public void del(Integer id) {
      BlackList model = (BlackList)this.blackListMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("black_id", id)).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      this.blackListMapper.delete((Wrapper)(new QueryWrapper()).eq("black_id", id));
   }

   // $FF: synthetic method
   private static Object $deserializeLambda$(SerializedLambda lambda) {
      switch (lambda.getImplMethodName()) {
         case "getIp":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/BlackList") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return BlackList::getIp;
            }
         default:
            throw new IllegalArgumentException("Invalid lambda deserialization");
      }
   }
}
